searchData={"items":[{"type":"module","title":"ExDbug","doc":"# ExDbug\n\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_dbug.svg)](https://hex.pm/packages/ex_dbug)\n[![Docs](https://img.shields.io/badge/hex-docs-blue.svg)](https://hexdocs.pm/ex_dbug)\n\nDebug utility for Elixir applications, inspired by the Node.js 'debug' package. \nVersion 2.0 introduces decorator-based function tracing while maintaining compatibility with 1.x style debugging.","ref":"ExDbug.html"},{"type":"module","title":"Features - ExDbug","doc":"* 🎯 **Decorator-based function tracing** - Zero-cost, compile-time instrumentation\n* 🔄 **1.x Compatibility Mode** - Seamless upgrade path from earlier versions\n* 🔍 **Namespace-based filtering** - Filter debug output by context\n* 📊 **Rich metadata support** - Attach and format detailed debug information\n* ⚡ **Zero runtime cost when disabled** - Compile-time optimization\n* 🌍 **Environment variable-based filtering** - Easy runtime control\n* 📝 **Automatic metadata truncation** - Smart handling of large values\n* 🔧 **Hierarchical configuration** - Global, module, and function-level settings\n* 📈 **Value tracking** - Monitor values through pipelines\n* ⏱️ **Optional timing and stack traces** - Deep insights when needed","ref":"ExDbug.html#module-features"},{"type":"module","title":"Installation - ExDbug","doc":"Add `ex_dbug` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_dbug, \"~> 2.0\"}\n  ]\nend\n```","ref":"ExDbug.html#module-installation"},{"type":"module","title":"Usage (2.0 Style) - ExDbug","doc":"The new decorator-based approach makes debugging more elegant and maintainable:\n\n```elixir\ndefmodule MyApp.Worker do\n  use ExDbug, enabled: true\n\n  # Simple debug trace\n  @decorate dbug()\n  def process(data) do\n    # Implementation\n  end\n\n  # Configured debug trace\n  @decorate dbug(context: :important)\n  def process_important(data) do\n    # Implementation\n  end\n\n  # Debug all functions in module\n  @decorate_all dbug()\n  \n  def bulk_1(arg), do: arg\n  def bulk_2(arg), do: arg\nend\n```","ref":"ExDbug.html#module-usage-2-0-style"},{"type":"module","title":"Compatibility Mode (1.x Style) - ExDbug","doc":"For existing projects or gradual migration, use compatibility mode:\n\n```elixir\ndefmodule MyApp.LegacyWorker do\n  use ExDbug, compatibility_mode: true\n\n  def process(data) do\n    dbug(\"Processing data\", size: byte_size(data))\n    # ... processing logic\n    dbug(\"Completed processing\", status: :ok)\n  end\nend\n```","ref":"ExDbug.html#module-compatibility-mode-1-x-style"},{"type":"module","title":"Configuration - ExDbug","doc":"","ref":"ExDbug.html#module-configuration"},{"type":"module","title":"Compile-Time Configuration - ExDbug","doc":"In your `config.exs`:\n\n```elixir\nconfig :ex_dbug,\n  enabled: true,\n  config: [\n    max_depth: 3,\n    include_timing: true,\n    include_stack: true,\n    truncate: 100,\n    levels: [:debug, :error]\n  ]\n```","ref":"ExDbug.html#module-compile-time-configuration"},{"type":"module","title":"Module-Level Configuration - ExDbug","doc":"```elixir\nuse ExDbug,\n  enabled: true,\n  max_depth: 5,\n  include_timing: true,\n  include_stack: false,\n  levels: [:debug, :error]\n```","ref":"ExDbug.html#module-module-level-configuration"},{"type":"module","title":"Function-Level Configuration (2.0) - ExDbug","doc":"```elixir\n@decorate dbug(\n  context: :important,\n  include_timing: true,\n  include_stack: true\n)\ndef critical_function(arg) do\n  # Implementation\nend\n```","ref":"ExDbug.html#module-function-level-configuration-2-0"},{"type":"module","title":"Runtime Configuration - ExDbug","doc":"Control debug output using the `DEBUG` environment variable:\n\n```bash\n# Enable all debug output\nDEBUG=\"*\" mix run\n\n# Enable specific namespace\nDEBUG=\"myapp:worker\" mix run\n\n# Enable multiple patterns\nDEBUG=\"myapp:*,other:thing\" mix run\n\n# Enable all except specific namespace\nDEBUG=\"*,-myapp:secret\" mix run\n```","ref":"ExDbug.html#module-runtime-configuration"},{"type":"module","title":"Migrating from 1.x to 2.0 - ExDbug","doc":"","ref":"ExDbug.html#module-migrating-from-1-x-to-2-0"},{"type":"module","title":"Option 1: Direct Upgrade (Recommended) - ExDbug","doc":"Replace debug calls with decorators:\n```elixir\n# Before (1.x)\ndef process(arg) do\n  dbug(\"Processing\", value: arg)\n  # Implementation\nend\n\n# After (2.0)\n@decorate dbug()\ndef process(arg) do\n  # Implementation\nend\n```","ref":"ExDbug.html#module-option-1-direct-upgrade-recommended"},{"type":"module","title":"Option 2: Compatibility Mode - ExDbug","doc":"For gradual migration, enable compatibility mode:\n\n```elixir\nuse ExDbug, compatibility_mode: true\n# All 1.x code continues to work\n```","ref":"ExDbug.html#module-option-2-compatibility-mode"},{"type":"module","title":"Configuration Updates - ExDbug","doc":"Update your configuration to use the new hierarchical structure:\n\n```elixir\n# Before (1.x)\nconfig :ex_dbug, enabled: true\n\n# After (2.0)\nconfig :ex_dbug,\n  enabled: true,\n  config: [\n    max_depth: 3,\n    include_timing: true\n  ]\n```","ref":"ExDbug.html#module-configuration-updates"},{"type":"module","title":"Best Practices - ExDbug","doc":"1. Use descriptive context names matching your application structure\n2. Prefer decorator-based debugging for new code\n3. Use compatibility mode for gradual migration\n4. Set appropriate DEBUG patterns for different environments\n5. Configure hierarchically (global → module → function)\n6. Disable in production for zero overhead","ref":"ExDbug.html#module-best-practices"},{"type":"module","title":"Production Use - ExDbug","doc":"While ExDbug has minimal overhead when disabled, it's recommended to set \n`config :ex_dbug, enabled: false` in production unless debugging is specifically \nneeded. This ensures zero runtime cost as debug calls are compiled out completely.","ref":"ExDbug.html#module-production-use"},{"type":"function","title":"ExDbug.format_output/4","doc":"","ref":"ExDbug.html#format_output/4"},{"type":"type","title":"ExDbug.debug_opts/0","doc":"","ref":"ExDbug.html#t:debug_opts/0"},{"type":"module","title":"ExDbug.Compatibility","doc":"","ref":"ExDbug.Compatibility.html"},{"type":"macro","title":"ExDbug.Compatibility.dbug/2","doc":"","ref":"ExDbug.Compatibility.html#dbug/2"},{"type":"macro","title":"ExDbug.Compatibility.error/2","doc":"","ref":"ExDbug.Compatibility.html#error/2"},{"type":"macro","title":"ExDbug.Compatibility.track/2","doc":"","ref":"ExDbug.Compatibility.html#track/2"},{"type":"module","title":"ExDbug.Decorators","doc":"","ref":"ExDbug.Decorators.html"},{"type":"macro","title":"ExDbug.Decorators.dbug/0","doc":"","ref":"ExDbug.Decorators.html#dbug/0"},{"type":"macro","title":"ExDbug.Decorators.dbug/1","doc":"","ref":"ExDbug.Decorators.html#dbug/1"},{"type":"function","title":"ExDbug.Decorators.dbug/2","doc":"","ref":"ExDbug.Decorators.html#dbug/2"},{"type":"function","title":"ExDbug.Decorators.dbug/3","doc":"","ref":"ExDbug.Decorators.html#dbug/3"},{"type":"extras","title":"ExDbug","doc":"# ExDbug\n\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_dbug.svg)](https://hex.pm/packages/ex_dbug)\n[![Docs](https://img.shields.io/badge/hex-docs-blue.svg)](https://hexdocs.pm/ex_dbug)\n\nDebug utility for Elixir applications, inspired by the Node.js 'debug' package. \nVersion 2.0 introduces decorator-based function tracing while maintaining compatibility with 1.x style debugging.","ref":"readme.html"},{"type":"extras","title":"Features - ExDbug","doc":"* 🎯 **Decorator-based function tracing** - Zero-cost, compile-time instrumentation\n* 🔄 **1.x Compatibility Mode** - Seamless upgrade path from earlier versions\n* 🔍 **Namespace-based filtering** - Filter debug output by context\n* 📊 **Rich metadata support** - Attach and format detailed debug information\n* ⚡ **Zero runtime cost when disabled** - Compile-time optimization\n* 🌍 **Environment variable-based filtering** - Easy runtime control\n* 📝 **Automatic metadata truncation** - Smart handling of large values\n* 🔧 **Hierarchical configuration** - Global, module, and function-level settings\n* 📈 **Value tracking** - Monitor values through pipelines\n* ⏱️ **Optional timing and stack traces** - Deep insights when needed","ref":"readme.html#features"},{"type":"extras","title":"Installation - ExDbug","doc":"Add `ex_dbug` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_dbug, \"~> 2.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage (2.0 Style) - ExDbug","doc":"The new decorator-based approach makes debugging more elegant and maintainable:\n\n```elixir\ndefmodule MyApp.Worker do\n  use ExDbug, enabled: true\n\n  # Simple debug trace\n  @decorate dbug()\n  def process(data) do\n    # Implementation\n  end\n\n  # Configured debug trace\n  @decorate dbug(context: :important)\n  def process_important(data) do\n    # Implementation\n  end\n\n  # Debug all functions in module\n  @decorate_all dbug()\n  \n  def bulk_1(arg), do: arg\n  def bulk_2(arg), do: arg\nend\n```","ref":"readme.html#usage-2-0-style"},{"type":"extras","title":"Compatibility Mode (1.x Style) - ExDbug","doc":"For existing projects or gradual migration, use compatibility mode:\n\n```elixir\ndefmodule MyApp.LegacyWorker do\n  use ExDbug, compatibility_mode: true\n\n  def process(data) do\n    dbug(\"Processing data\", size: byte_size(data))\n    # ... processing logic\n    dbug(\"Completed processing\", status: :ok)\n  end\nend\n```","ref":"readme.html#compatibility-mode-1-x-style"},{"type":"extras","title":"Configuration - ExDbug","doc":"","ref":"readme.html#configuration"},{"type":"extras","title":"Compile-Time Configuration - ExDbug","doc":"In your `config.exs`:\n\n```elixir\nconfig :ex_dbug,\n  enabled: true,\n  config: [\n    max_depth: 3,\n    include_timing: true,\n    include_stack: true,\n    truncate: 100,\n    levels: [:debug, :error]\n  ]\n```","ref":"readme.html#compile-time-configuration"},{"type":"extras","title":"Module-Level Configuration - ExDbug","doc":"```elixir\nuse ExDbug,\n  enabled: true,\n  max_depth: 5,\n  include_timing: true,\n  include_stack: false,\n  levels: [:debug, :error]\n```","ref":"readme.html#module-level-configuration"},{"type":"extras","title":"Function-Level Configuration (2.0) - ExDbug","doc":"```elixir\n@decorate dbug(\n  context: :important,\n  include_timing: true,\n  include_stack: true\n)\ndef critical_function(arg) do\n  # Implementation\nend\n```","ref":"readme.html#function-level-configuration-2-0"},{"type":"extras","title":"Runtime Configuration - ExDbug","doc":"Control debug output using the `DEBUG` environment variable:\n\n```bash\n# Enable all debug output\nDEBUG=\"*\" mix run\n\n# Enable specific namespace\nDEBUG=\"myapp:worker\" mix run\n\n# Enable multiple patterns\nDEBUG=\"myapp:*,other:thing\" mix run\n\n# Enable all except specific namespace\nDEBUG=\"*,-myapp:secret\" mix run\n```","ref":"readme.html#runtime-configuration"},{"type":"extras","title":"Migrating from 1.x to 2.0 - ExDbug","doc":"","ref":"readme.html#migrating-from-1-x-to-2-0"},{"type":"extras","title":"Option 1: Direct Upgrade (Recommended) - ExDbug","doc":"Replace debug calls with decorators:\n```elixir\n# Before (1.x)\ndef process(arg) do\n  dbug(\"Processing\", value: arg)\n  # Implementation\nend\n\n# After (2.0)\n@decorate dbug()\ndef process(arg) do\n  # Implementation\nend\n```","ref":"readme.html#option-1-direct-upgrade-recommended"},{"type":"extras","title":"Option 2: Compatibility Mode - ExDbug","doc":"For gradual migration, enable compatibility mode:\n\n```elixir\nuse ExDbug, compatibility_mode: true\n# All 1.x code continues to work\n```","ref":"readme.html#option-2-compatibility-mode"},{"type":"extras","title":"Configuration Updates - ExDbug","doc":"Update your configuration to use the new hierarchical structure:\n\n```elixir\n# Before (1.x)\nconfig :ex_dbug, enabled: true\n\n# After (2.0)\nconfig :ex_dbug,\n  enabled: true,\n  config: [\n    max_depth: 3,\n    include_timing: true\n  ]\n```","ref":"readme.html#configuration-updates"},{"type":"extras","title":"Best Practices - ExDbug","doc":"1. Use descriptive context names matching your application structure\n2. Prefer decorator-based debugging for new code\n3. Use compatibility mode for gradual migration\n4. Set appropriate DEBUG patterns for different environments\n5. Configure hierarchically (global → module → function)\n6. Disable in production for zero overhead","ref":"readme.html#best-practices"},{"type":"extras","title":"Production Use - ExDbug","doc":"While ExDbug has minimal overhead when disabled, it's recommended to set \n`config :ex_dbug, enabled: false` in production unless debugging is specifically \nneeded. This ensures zero runtime cost as debug calls are compiled out completely.","ref":"readme.html#production-use"},{"type":"extras","title":"Contributing - ExDbug","doc":"1. Fork it\n2. Create your feature branch (`git checkout -b my-new-feature`)\n3. Commit your changes (`git commit -am 'Add some feature'`)\n4. Push to the branch (`git push origin my-new-feature`)\n5. Create new Pull Request","ref":"readme.html#contributing"},{"type":"extras","title":"License - ExDbug","doc":"MIT License - see LICENSE.md for details.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}